@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2015 - 2016, Met Office
+# (C) British Crown Copyright 2015 - 2017, Met Office
 #
 # This file is part of cf_units.
 #
@@ -21,7 +21,7 @@ Provision of a wrapper class to support Unidata/UCAR UDUNITS-2, and the
 netcdftime calendar functionality.
 
 See also: `UDUNITS-2
-<http://www.unidata.ucar.edu/software/udunits/udunits-2/udunits2.html>`_.
+<http://www.unidata.ucar.edu/software/udunits>`_.
 
 """
 
@@ -685,9 +685,8 @@ def date2num(date, unit, calendar):
     unit_string = unit.rstrip(" UTC")
     if unit_string.endswith(" since epoch"):
         unit_string = unit_string.replace("epoch", EPOCH)
-    cdftime = netcdftime.utime(unit_string, calendar=calendar)
-    date = _discard_microsecond(date)
-    return cdftime.date2num(date)
+    unit_inst = Unit(unit_string, calendar=calendar)
+    return unit_inst.date2num(date)
 
 
 def _discard_microsecond(date):
@@ -785,8 +784,8 @@ def num2date(time_value, unit, calendar):
     unit_string = unit.rstrip(" UTC")
     if unit_string.endswith(" since epoch"):
         unit_string = unit_string.replace("epoch", EPOCH)
-    cdftime = netcdftime.utime(unit_string, calendar=calendar)
-    return _num2date_to_nearest_second(time_value, cdftime)
+    unit_inst = Unit(unit_string, calendar=calendar)
+    return unit_inst.num2date(time_value)
 
 
 def _num2date_to_nearest_second(time_value, utime):
@@ -1210,6 +1209,35 @@ class Unit(_OrderedHashable):
         """
         return self.calendar is not None
 
+    def is_long_time_interval(self):
+        """
+        Defines whether this unit describes a time unit with a long time
+        interval ("months" or "years"). These long time intervals *are*
+        supported by `UDUNITS2` but are not supported by `netcdftime`. This
+        discrepancy means we cannot run self.num2date() on a time unit with
+        a long time interval.
+
+        Returns:
+            Boolean.
+
+        For example:
+
+            >>> import cf_units
+            >>> u = cf_units.Unit('days since epoch')
+            >>> u.is_long_time_interval()
+            False
+            >>> u = cf_units.Unit('years since epoch')
+            >>> u.is_long_time_interval()
+            True
+
+        """
+        result = False
+        long_time_intervals = ['year', 'month']
+        if self.is_time_reference():
+            result = any(interval in self.origin
+                         for interval in long_time_intervals)
+        return result
+
     def title(self, value):
         """
         Return the unit value as a title string.
@@ -1642,12 +1670,12 @@ class Unit(_OrderedHashable):
         For example:
 
             >>> import cf_units
-            >>> u = cf_units.Unit('meters')
+            >>> u = cf_units.Unit('miles/hour')
             >>> str(u)
-            'meters'
+            'miles/hour'
 
         """
-        return self.origin or self.name
+        return self.origin or self.symbol
 
     def __repr__(self):
         """
@@ -2069,13 +2097,20 @@ class Unit(_OrderedHashable):
             datetime.datetime(1970, 1, 1, 2, 0)
 
         """
-
-        #
-        # ensure to strip out non-parsable 'UTC' postfix which
-        # is generated by UDUNITS-2 formatted output
-        #
         if self.calendar is None:
             raise ValueError('Unit has undefined calendar')
+
+        # `netcdftime` cannot parse long time intervals ("months" or "years").
+        if self.is_long_time_interval():
+            interval = self.origin.split(' ')[0]
+            emsg = ('Time units with interval of "months", "years" '
+                    '(or singular of these) cannot be processed, got {!r}.')
+            raise ValueError(emsg.format(interval))
+
+        #
+        # ensure to strip out non-parsable 'UTC' postfix, which
+        # is generated by UDUNITS-2 formatted output
+        #
         return netcdftime.utime(str(self).rstrip(" UTC"), self.calendar)
 
     def date2num(self, date):
